@@ -308,6 +308,11 @@ class TerraformParser(object):
                     if Defaults.r_mount_addr_ptr_list not in self.resources[target_resource]:
                         self.resources[target_resource][Defaults.r_mount_addr_ptr_list] = []
 
+                    # ensure resources[target_resource]['values'] is an
+                    # empty dict and not None
+                    if not self.resources[target_resource]['values']:
+                        self.resources[target_resource]['values'] = dict()
+
                     if ref_type not in self.resources[target_resource]['values']:
                         self.resources[target_resource]['values'][ref_type] = []
 
@@ -343,10 +348,18 @@ class TerraformParser(object):
                 if not key.startswith(module_address):
                     continue
 
-                # Possibly module (or resource) is using foreach/count
-                k = strip_iterations(key)
-                if k == strip_iterations(full_address):
-                    resource_list.append(key)
+                # Check if the resource/module has iterations
+                if '[' in key:
+                    # Possibly module (or resource) is using foreach/count
+                    k = strip_iterations(key)
+                    if k == strip_iterations(full_address):
+                        resource_list.append(key)
+                else:
+                    # Resource/module does not have any iteration
+                    # Additionally, the resource we are looking under this module is coming from another
+                    # module output. Thus, we need to dive a bit deeper.
+                    if resource_name.startswith('module') and key.startswith('module'):
+                        resource_list.append(key)
 
             if resource_list:
                 return resource_list
@@ -354,6 +367,8 @@ class TerraformParser(object):
         resource_type, resource_id = resource_name.split('.')[0:2]
 
         if resource_type == 'module':
+            # TODO: This wont work correctly, if an output is used within a module, coming from another module.
+            #       Fix multi-layer module structure for the outputs ?
             module_name, output_id = resource_name.split('.')[1:3]
             module = self.raw['configuration']['root_module'].get('module_calls', {}).get(module_name, {})
 
